@@ -92,13 +92,14 @@ const SharingDialog = new Lang.Class({
                                        transient_for: toplevel,
                                        modal: true,
                                        destroy_with_parent: true,
+                                       use_header_bar: true,
                                        width_request: 335,
                                        margin_top: 5,
                                        title: _("Sharing Settings"),
                                        hexpand: true });
 
         // Label for Done button in Sharing dialog
-        this.widget.add_button(_("Done"), Gtk.ResponseType.OK);
+        this.widget.add_button(_("Done"), Gtk.ResponseType.CLOSE);
 
         let mainGrid = new Gtk.Grid({ orientation: Gtk.Orientation.VERTICAL,
                                       column_spacing: 6,
@@ -328,7 +329,7 @@ const SharingDialog = new Lang.Class({
     // Get the id of the selected doc from the sourceManager, give auth info to Google, and start the service
     _createGDataEntry: function() {
         // Query the service for the entry related to the doc
-        this._service.query_single_entry_async(this._service.get_primary_authorization_domain(),
+        this._service.query_single_entry_async(GData.DocumentsService.get_primary_authorization_domain(),
             this._doc.identifier, null, GData.DocumentsText, null, Lang.bind(this,
                 function(object, res) {
                     try {
@@ -464,7 +465,7 @@ const SharingDialog = new Lang.Class({
 
         this._contactEntry.set_sensitive(false);
 
-        this._service.insert_entry_async(this._service.get_primary_authorization_domain(),
+        this._service.insert_entry_async(GData.DocumentsService.get_primary_authorization_domain(),
             aclLink.get_uri(), accessRule, null, Lang.bind(this,
                 function(service, res) {
                     this._contactEntry.set_sensitive(true);
@@ -503,7 +504,7 @@ const SharingDialog = new Lang.Class({
         let accessRule = new GData.AccessRule({ scope_type: scopeType,
                                                 role: role });
 
-        this._service.insert_entry_async(this._service.get_primary_authorization_domain(),
+        this._service.insert_entry_async(GData.DocumentsService.get_primary_authorization_domain(),
             aclLink.get_uri(), accessRule, null, Lang.bind(this,
                 function(service, res) {
                     try {
@@ -560,7 +561,7 @@ const SharingDialog = new Lang.Class({
             let accessRule = entries[idx];
             accessRule.set_role(newRole);
 
-            this._service.update_entry_async(this._service.get_primary_authorization_domain(),
+            this._service.update_entry_async(GData.DocumentsService.get_primary_authorization_domain(),
                 accessRule, null, Lang.bind(this,
                     function(service, res) {
                         try {
@@ -577,7 +578,7 @@ const SharingDialog = new Lang.Class({
             // If we are changing the permission to private, delete the public entry.
             let accessRule = entries[idx];
 
-            this._service.delete_entry_async(this._service.get_primary_authorization_domain(),
+            this._service.delete_entry_async(GData.DocumentsService.get_primary_authorization_domain(),
                 accessRule, null, Lang.bind(this,
                     function(service, res) {
                         try {
@@ -594,7 +595,7 @@ const SharingDialog = new Lang.Class({
             // Workaround if the doc is shared with link: step 1 delete shared with link permission.
             let accessRule = entries[idx];
 
-            this._service.delete_entry_async(this._service.get_primary_authorization_domain(),
+            this._service.delete_entry_async(GData.DocumentsService.get_primary_authorization_domain(),
                 accessRule, null, Lang.bind(this,
                     function(service, res) {
                         try {
